# LabelledObject

Establishes an association between Labels and an object in the Agilicus API. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**object_id** | **str** | Unique identifier | 
**object_type** | [**ObjectType**](ObjectType.md) |  | 
**labels** | [**[LabelAssociation]**](LabelAssociation.md) | The labels associated with the object | 
**org_id** | **str** | Unique identifier | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


